title: Eco-conception, le brouillard à venir
url: https://gauthierroussilhe.com/post/ecoconception-critique.html
hash_url: 059ace3d9bcdbd911d83f1da84ced326

<p>
    Ce qu’on nomme “éco-conception numérique”, c’est-à-dire, concevoir des services numériques pertinents tout en réduisant leur empreinte environnementale, a commencé à avoir le vent en poupe depuis deux ans. Aujourd’hui, ce champ connait une accélération fulgurante et de nouveaux acteurs arrivent chaque jour. Cette accélération est liée à l’avancée réglementaire et sociale de ces deux dernières années sur le sujet. Des nouveaux fonds publics et des aides y sont dédiés, les cahiers des charges évoluent dans ce sens et des offres se structurent. Bref, ce secteur d’activité arrive à une nouvelle phase de maturité. Ainsi, les acteurs plus anciens se mettent sur la défensive pour protéger leurs “parts de marché” au fur et à mesure que des acteurs “plus larges d’épaules” (ESN, agences de conseil, etc.) affluent. Ce qui était hier un petit marché et surtout un champ de recherche et de pratiques devient un marché plus ou moins important et on assiste, selon moi, à un mouvement de fermeture des savoirs, alimenté par la crainte de voir ses activités phagocytées. Cette crainte est légitime dans le sens où les organisations et personnes en demande (administration publique, collectivités, entreprises du numérique, etc.) n’ont pas le bagage nécessaire pour déterminer si un prestataire est réellement compétent ou non. Dans un mouvement contraire à celui que j’observe aujourd’hui, je souhaite ouvrir ma méthodologie et, en même temps, opérer un bilan critique pour améliorer la demande et donner quelques conseils pour mieux choisir son prestataire.
</p>

<h3>Table des matières</h3>
<a href="#existant">Quel existant ?</a><br/>
<a href="#methodo">Marchés et méthodologies</a><br/>
<a href="#optimiser">Est-ce qu’optimiser un service c’est éco-concevoir ?</a><br/>
<a href="#miracle">L’éco-conception numérique n’est pas une solution miracle</a><br/>
<a href="#deficit">Le déficit de formation</a><br/>
<a href="#conseils">Conseils pour les années à venir</a><br/>
<br/>

<h3 id="existant">Quel existant ?</h3>

<p>
    Quand on commence à s’intéresser au sujet de l’éco-conception numérique on tombe assez rapidement sur quelques documents pratiques comme les 115 bonnes pratiques de GreenIT et Frédéric Bordage, ou le référentiel de bonnes pratiques de l’Institut du Numérique Responsable (INR), ou encore, plus récemment, le guide de l’association “Designers Éthiques”. Le premier est très orienté vers les pratiques de programmation, le second et le troisième inclut en plus d’autres champs comme l’UX design, la stratégie, etc. Toutefois, avant de regarder ces documents techniques il est bien important de comprendre le cadre de l’éco-conception. Celui-ci est normé par des standards ISO comme le 14062:2002 (IEC 62430:2019 maintenant), cependant, cette norme est généraliste à l’éco-conception et n’est pas spécifique au numérique. Cela revient à dire que la conception d’un service numérique peut être appréhendée, d’un point de vue environnemental, comme la création de n’importe quel autre service. Cette assertion est partiellement vraie mais pose aussi des limites réelles à la mise en pratique comme nous allons le voir.
</p>

<h3 id="methodo">Marchés et méthodologies</h3>
<p>
    Au cours des quatre dernières années, j’ai été alimenté par une bonne partie de la littérature existante et j’ai surtout piloté des projets d’éco-conception numérique en “conditions réelles” avec différents types de clients. À partir de cette digestion et de cette pratique j’en ai tiré ma méthodologie “sur-mesure” qui correspond à mes connaissances et ma vision des choses. Cette méthodologie a pour but de poser les bases de mon accompagnement en éco-conception et de mettre en lumière les points cruciaux pour les arbitrages tout au long du projet. 
</p>

<p>
    Dans un premier temps, j’ai sélectionné 3 conditions (ou points de départs) qui n’ont rien d’exceptionnels ou nouveaux :
</p>
<ol class="list">
    <li class="list-item">
    <p class="item-name">1 → On doit réduire l’empreinte environnementale du service, qu’il soit numérique ou non ;</p>
    </li>
    <li class="list-item"> 
    <p class="item-name">2 → On doit répondre avec pertinence aux besoins exprimés par les usagers ;</p>
    </li>
    <li class="list-item"> 
    <p class="item-name">3 → Il faut partir du principe que la numérisation n’est pas forcément la meilleure option pour répondre aux deux premiers points.</p> 
    </li>
</ol>
<p>
    Je tiens à appuyer sur le troisième point et ainsi formuler mon premier conseil : <b>si la personne qui vous accompagne sur l’éco-conception numérique ne questionne pas sincèrement et souvent la numérisation de votre service (ou produit si on parle d’agilité) ou la numérisation de certains fonctions de celui-ci alors il y a de fortes chances qu’elle n’est pas bien compris le but de l’éco-conception</b>. Je ne dis pas que ce questionnement est facile, j’ai moi-même échoué à travailler en profondeur sur cette question sur un gros projet que j’accompagne mais cela ne m’empêche de requestionner régulièrement l’équipe projet là-dessus. À terme, le métier devra mieux s’outiller pour accompagner sur ce questionnement de fond.
</p>

<p>
    Dans un second temps, lorsque les conditions sont remplies, je pose sept piliers qui guideront le processus de numérisation :</p>

<ol class="list">
    <li class="list-item">
    <p class="item-name">→ Le service doit favoriser la durée de vie des équipements ;</p>
    </li>
    <li class="list-item"> 
    <p class="item-name">→ Le service doit réduire la consommation de ressources (environnement comme informatique) en valeur absolue ;</p>
    </li>
    <li class="list-item"> 
    <p class="item-name">→ Le service doit favoriser sa propre durée de vie en répondant à des besoins pertinents à moyen et long terme et en facilitant le travail de maintenance et d’évolution ;</p> 
    </li>
    <li class="list-item"> 
    <p class="item-name">→ Le service doit être optimisé pour les conditions d’accès les plus difficiles (équipement ancien ou peu puissant, peu de réseau, données payantes) ;</p> 
    </li>
    <li class="list-item"> 
    <p class="item-name">→ L’éco-conception numérique n’est que la partie d’un cercle vertueux qui intègre accessibilité, respect de la vie privée, open data, logiciel libre, etc… ;</p>
    </li>
    <li class="list-item"> 
    <p class="item-name">→ Le partage et la documentation du travail effectué doit être la norme, pas l’exception ;</p> 
    </li>
    <li class="list-item"> 
    <p class="item-name">→ Le travail effectué doit être mesuré et doit s’intégrer dans une démarche pré-existante de transformation écologique.</p>
    </li>
</ol>

<p>
     Tous ces piliers se répondent les uns les autres et doivent donc être pris tous ensemble pour tenir l’édifice du projet. De même, derrière chaque pilier il y a de nombreuses bonnes pratiques, indicateurs, méthodes d’arbitrage que je ne peux pas expliquer ici par manque de temps. Une fois encore, je vais m’appuyer sur un seul pilier, le cinquième, pour fournir un second conseil : <b>l’éco-conception numérique peut être vu dans une couche supplémentaire à un cahier des charges toujours plus complexe. Pour moi il est l’opposé, c’est un prétexte supplémentaire pour mutualiser l’effort et pour faire advenir un environnement numérique de qualité d’un seul mouvement (accessibilité, logiciel libre, sécurité, etc.)</b>. Je ne fais pas d’éco-conception numérique sans amener d’accessibilité web ou sans essayer de “dégafamiser” au maximum le service. Si votre prestataire ne se bat pas sur ce point alors il ne vous rend pas service.  Par exemple, proposer un AWS (Amazon Web Services ou autres services cloud de Google ou Microsoft) dans le cadre d’une mission d’éco-conception numérique est un contre-sens pour moi, hors besoins exceptionnels. Ajouter une couche qui va complexifier dans les enjeux de RGPD et de souveraineté sous prétexte qu’Amazon annoncerait des centres de données “verts” est une erreur stratégique. Toute la vertu vient ensemble ou rien ne vient.
</p>

<figure class="img-figure-large"><div class="img-wrapper" style="padding-bottom: 68%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-ecoconception-01.svg"></div><figcaption>Récapitulatif de la méthodologie 3+7</figcaption></figure>

<p>
    Voilà un bref aperçu de ma méthodologie personnelle, elle n’est pas figée et continuera d’évoluer (de nouveaux piliers vont apparaître). Je ne conseillerais pas de l'utiliser car je l'ai ajustée spécialement par rapport à mes connaissances et à ma vision du sujet. En tout cas, cette introduction aura permis de bien souligner deux conseils qui me semblent clé dans le choix de son prestataire et dans la compréhension d’un accompagnement qualitatif.
</p>

<h3 id="optimiser">Est-ce qu’optimiser un service c’est éco-concevoir ?</h3>

<p>
    Lorsque j’accompagne un projet j’utilise la méthodologie présentée ci-dessus pour faire le cadrage. En complément, j’utilise différents indicateurs techniques pour suivre l’évolution du produit. Cela peut paraître contre-intuitif mais je n’intègre pas d’indicateurs environnementaux dans le projet (gCO<sub>2</sub>e, cl d’eau ou autres) car ce sont des ordres de grandeur approximatifs obtenus à partir d’indicateurs techniques que j’intègre dans le suivi. Les indicateurs environnementaux ont, selon moi, une utilité pour la communication <i>a posteriori</i> mais ne sont pas pertinents dans la conduite d’un projet. Si l’on suit bien les piliers et les indicateurs fournis on arrive alors à un service numérique très léger et très optimisé. Par exemple, j’ai récemment aidé à la refonte du site web de <a href="https://commown.coop/" rel="noopener noreferrer">Commown</a> avec <a href="https://timothee.goguely.com/" rel="noopener noreferrer">Timothée Goguely</a> et <a href="https://www.pikselkraft.com/" rel="noopener noreferrer">Derek Salmon</a>. Avec la nouvelle version nous avons divisé le poids moyen des pages par 22, le nombre de requêtes par 4, réduit le temps de la First Contentful Paint (FCP) par 5 et le Time to Interactive (T2I) par 11. 
</p>

<figure class="img-figure-large"><div class="img-wrapper" style="padding-bottom: 75%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-ecoconception-02.svg"></div><figcaption>Suivi des indicateurs techniques pour la refonte du site web de Commown</figcaption></figure>

<p>
    C’est bien mais est-ce que c’est vraiment de l’éco-conception ? Si on enlève l’étape de questionnement sur ce qu’on numérise ou pas alors nous n’avons fait que de l’optimisation. En effet, la comparaison Avant/Après ne donne pas à voir la démarche d’éco-conception, c’est plus la photo sur la ligne d’arrivée que la vidéo de la course. Nous avons travaillé avec Commown en amont pour supprimer au moins la moitié du contenu préexistant, nous avons questionné systématiquement les besoins exprimés et l’intérêt de numériser pour y répondre. Ce processus a été d’autant plus agréable que Commown voulait être conforme au RGAA (Référentiel d’accessibilité web) et dégafamiser au maximum leurs outils. Tout est voulu ensemble donc l’accompagnement a pu être réussi. Au final, les services numériques dont j’ai aidé à l’éco-conception ont des scores quasi-maximum sur les outils de performance web populaires. Alors est-ce que éco-concevoir consiste juste à optimiser un service ?
</p>

<p>
    La plupart des métiers du web consiste à optimiser des choses parfois lourdes, tentaculaires et le processus d’optimisation peut lui-même amener à une certaine voracité en ressources informatiques. <b>Si on s’inspire du principe de Pareto l’éco-conception consiste d’une certaine façon à utiliser seulement 20% des ressources données pour répondre à 80% des besoins exprimés par les usagers</b>. C’est ici que s’exprime l’idée de la sobriété numérique. Cette idée concerne autant la conception du service que les dispositifs et flux matériels nécessaires à son fonctionnement. Moins le service fait appel à des ressources externes (dépendances et librairies externes, tiers-parties, etc.) et à des ressources informatiques (puissance CPU/RAM, débit réseau) et plus le service sera résistant en cas de réduction des flux (réseau saturé ou restreint) ou en cas d’évènements exceptionnels (catastrophes naturelles, coupure de câbles, panne serveur, etc.). De même, une démarche d’éco-conception et de sobriété numérique vise à réduire la dépendance à des services monopolistiques qui auront plus tard toute latitude sur leur politique tarifaire et sur les politiques d’accès à leurs services. 
</p>

<p>
    Il faut donc retenir que l’éco-conception doit être cadrée par des principes desquelles découlent des indicateurs. Des indicateurs sans les principes mentionnés plus haut ne garantissent en rien la qualité d’une démarche d’éco-conception. De plus, une démarche d’éco-conception ne vient jamais seule, elle doit être accompagnée de questionnements sur l’accessibilité, la souveraineté, le respect de la vie privée, la sécurité, etc. Un dernier point me semble particulièrement important : éco-concevoir un service numérique implique aussi de questionner la politique d’achat d’équipements de l’organisation dans laquelle on intervient. C’est hors du périmètre de la mission initiale mais c’est un point essentiel, il est sans doute plus important de convaincre une large entreprise de rallonger la durée de vie de son parc d’équipements numériques que d’éco-concevoir un service (sauf si c’est un service public essentiel). L’idéal c’est de faire les deux à la fois mais ces missions dépassent généralement les compétences d’une agence web.
</p>


<h3 id="miracle">L’éco-conception numérique n’est pas une solution miracle</h3>

<p>
    L’éco-conception numérique porte en elle tous les éléments pour faire advenir des pratiques de greenwashing : mauvaise connaissances du sujet par les demandeurs, faible niveau de compétences des prestataires, pression pour mettre en place des actions et positionnement des GAFAM sur le sujet. De plus, <b>entre éco-concevoir un service numérique et communiquer là-dessus, ou mettre en place une vraie stratégie environnementale et repenser fondamentalement son modèle économique, la première option est bien plus simple</b>. Le fait que Volkwagen Canada communique sur la création d’un <a href="https://www.vw.ca/carbonneutralnet/fr/" rel="noopener noreferrer">site web écologique</a> qui fait la promotion de SUV électrique est, d’une part, le coup de départ de ce cycle de greenwashing et, d’autre part, le summum du cynisme car ce site est en aucun cas éco-conçu ni même optimisé (au même titre que les SUV électriques ne sont pas la réponse à la transition énergétique et écologique).
</p>

<p>
    Au vu de ce contexte, il me semble que l’éco-conception numérique va être un levier pour des politiques de greenwashing. J’ai vu différentes campagnes, notamment de ClimateAction.Tech, visant à pousser des grandes entreprises à “éco-concevoir” leurs sites web (dans le monde anglo-saxon, cela correspond à réduire la consommation électrique et les émissions de carbone du site). En réponse à cela, <b>il serait extrêmement facile pour Total et consorts d’éco-concevoir leurs services numériques sans absolument rien changer à leurs activités. Ce processus leur permettrait même d’améliorer leur communication d’entreprises à peu de frais car les sites web sont le principal point de contact avec une entreprise maintenant</b>. Ainsi, je ne soutiens pas le principe selon lequel il faudrait proposer activement à des grandes entreprises, qui ne changent leurs actions qu’à la marge, d’éco-concevoir leurs services numériques.
</p>

<p>
    Pour moi il est clair que l’éco-conception numérique n’a de sens que dans une stratégie environnementale d’entreprise ambitieuse et cohérente et une volonté de l’appliquer en interne (via le top management et/ou les employés). De ce fait, j’ai travaillé pour des entreprises qui sont déjà alignées dans leur politique environnementale et l’éco-conception et la sobriété numérique ne font que suivre ce mouvement. <b>Selon mon expérience, cette paire n’a pas la force nécessaire pour être moteur d’une stratégie environnementale (pour de nombreuses raisons que je ne peux expliquer ici) et est bien plus facile à mettre en place lorsqu’elle est à l’abri dans le peloton (pour filer la métaphore cycliste)</b>. Pour vérifier la stratégie d’une entreprise qui me contacterait je regarde certes les rapports RSE mais j’observe surtout où sont fléchés les investissements de l’entreprise, c'est bien plus efficace pour voir la stratégie réelle au-delà du vernis de la communication. Au final, l’éco-conception n’engage en rien une entreprise à changer ses activités, c'est pourquoi je préfère refuser de travailler avec le secteur des énergies fossiles ou de l’agro-alimentaire industriel, et me concentrer sur les entreprises avec une stratégie sincère et établie et les administrations publiques.
</p>

<h3 id="deficit">Le déficit de formation</h3>
<p>
    Une des problématiques à laquelle nous allons devoir faire face rapidement est le manque de formation sur le sujet. Je suis à peu près certain qu’un master en sciences environnementales du numérique aurait un grand succès. Cependant, pour être pertinent sur le sujet il faut être multi-disciplinaire : une bonne connaissance des sciences environnementales, de l’infrastructure matérielle et logicielle du secteur numérique, et une bonne culture générale du développement logiciel/web et du design numérique sont de rigueur. Une telle formation demande une plasticité mentale importante pour suivre un projet au niveau macro/meso/micro. Ne couvrant pas moi-même toutes les connaissances demandées je travaille très souvent avec de nombreux collègues pour avoir une approche complète. De même, un arbitrage ne se règle pas que d’un point de vue technique ou de design, tout doit être réfléchi ensemble et cela rend l’exercice extrêmement complexe. <b>Une bonne compréhension du contexte d’application et du scénario d’usage sont un pré-requis à tout bon arbitrage</b>.
</p>

<p>
    Les personnes travaillant sur le sujet ont généralement été formées par des formations courtes chez GreenIT, l’INR (via MOOC), Ecoinfo ou DDemain. Cependant 3 jours ne suffisent pas à comprendre le sujet et beaucoup travaillent à côté pour améliorer leurs connaissances. Côté commanditaire, il y a encore peu de personnes qui savent comment écrire un cahier des charges pertinents ou qui savent tout simplement quoi demander parce que le sujet est vaste et complexe. Sans structuration de la formation des futurs professionnels du sujet, le flou continuera encore quelques années.
</p>

<h3 id="conseils">Conseils pour les années à venir</h3>
<p>
    Aujourd’hui le couple qu’on appelle l’éco-conception et la sobriété numérique, ou plus globalement <i>digital sustainability</i> en anglais, commence, me semble t-il, une période de greenwashing. Cela ne veut pas dire qu’il y aura pas des gens très compétents pour répondre à ce besoin, mais tout simplement qu’ils seront plus ou moins cachés par des acteurs moins compétents et moins pertinents mais avec les moyens d’être visibles. De même, des acteurs compétents refuseront, par éthique, de travailler avec certaines entreprises avec beaucoup de moyens et peu d’envie de changer leurs activités insoutenables. Alors les acteurs peu compétents mais visibles répondront à leur demande et distordront la pratique. Cela est bien sûr un scénario catastrophe dicté par une dynamique du moins-disant mais cela reste un risque fort, c’est pour cela que je souhaite l’énoncer. J’ai déjà assisté, par proxy, à une présentation de l’entreprise internationale de conseil Cybercom sur la “Digital Sustainability”, cela était tout simplement leur powerpoint pour vendre des solutions cloud (AWS / Azure) mais avec quelques diapositives sur l’alimentation en EnR des serveurs. Je vous laisse admirer cet enchainement de diapositives qui sous-entendrait que le cloud amène les émissions à 0. 
</p>

<figure class="img-figure"><div class="img-wrapper" style="padding-bottom: 55%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-ecoconception-03.jpg"></div></figure>
<figure class="img-figure"><div class="img-wrapper" style="padding-bottom: 55%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-ecoconception-04.jpg"></div></figure>
<figure class="img-figure"><div class="img-wrapper" style="padding-bottom: 55%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-ecoconception-05.jpg"></div><figcaption>Captures d'écran de la présentation de Cybercom "Digital Sustainability - How to do IT with net-positive approach?" du 26 mai 2021 (Cybercom)</figcaption></figure>

<p>
    Tous les guides pratiques du monde n’ont pas le pouvoir de changer l’appropriation du sujet par des acteurs avec peu de compétences et de convictions ou tout simplement avec une mauvaise compréhension des enjeux. Alors dans le brouillard à venir comment bien choisir avec qui travailler ? <b>Il me semble que le premier test est la capacité du prestataire à questionner la pertinence de la numérisation dans le cadre du projet. Cela permet de faire un premier tri avec les vendeurs de cloud déguisés mais aussi de faire le tri dans les entreprises qui font cela pour la communication</b>. Ensuite, soyez exigeant sur la définition des principes guidant la démarche, si l’on propose des indicateurs sans un cadre bien compris et contraignant alors on pédalera à vide. De plus, <b>si les autres parts vertueuses d’un environnement numérique de qualité ne sont pas intégrées alors on gaspille une partie de l’effort</b>. Finalement, une personne ne suffit pas à porter le poids d’une telle mission et la constitution d’une équipe est généralement nécessaire pour couvrir l’ensemble des problématiques (sciences environnementales, stratégie, design, développement, accessibilité, DevOps, etc.). Alors une mission d’éco-conception permet potentiellement d’ouvrir à la collaboration et à la transmission des savoirs entre pairs (en interne comme en externe). Bref, il va falloir lutter contre le brouillard / brouillage en continuant à ouvrir les connaissances et à trouver les bons alliés pour mutualiser l’énergie nécessaire pour faire advenir un environnement numérique de qualité dans les années à venir.
</p>
